bibliography.html

#### Bibliography

[Stroustrup] | Stroustrup: The Design and Evolution of C++, ISBN 0201543303
[Czarnecki] | Czarnecki, Eisenecker: Generative Programming, ISBN 0201309777
[Barton] | Barton, Nackman: Scientific and Engineering C++, ISBN 0201533936
[McConnell] | McConnell: Code Complete, ISBN 1556154844
[Std] | ISO/IEC 14882:1998 Programming Languages - C++
[Thompson] | Thompson: Haskell: The Craft of Functional Programming, ISBN 0201342758
[Okasaki] | Okasaki: Purely Functional Data Structures, ISBN 0521663504
[Cousineau] | Cousineau, Mauny: The Functional Approach to Programming, ISBN 0521576814
[Abelson] | Abelson, Sussman, Sussman: Structure and Interpretation of Computer Programs, ISBN 0521576814

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)